@@ -1,6 +1,6 @@
 package DBI::DBD::Metadata;
 
-# $Id: Metadata.pm,v 1.4 2004/01/07 17:38:51 timbo Exp $
+# $Id: Metadata.pm,v 1.5 2004/02/01 11:16:16 timbo Exp $
 #
 # Copyright (c) 1997-2003 Jonathan Leffler, Jochen Wiedmann,
 # Steffen Goeldner and Tim Bunce
@@ -21,7 +21,7 @@ use DBI::Const::GetInfoType qw(%GetInfoType);
 use strict;
 
 my
-$VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 =head1 NAME
 
@@ -245,7 +245,7 @@ A possible implementation of DBD::Driver::type_info_all() may look like:
   }
 
 Please replace Driver (or "<foo>") with the name of your driver.
-Note that this stub function is generated for you by the write_typeinfo
+Note that this stub function is generated for you by the write_typeinfo_pm
 function, but you must manually transfer the code to Driver.pm.
 
 =cut
@@ -305,9 +305,9 @@ sub fmt_value
     return $val;
 }
 
-sub write_typeinfo
+sub write_typeinfo_pm
 {
-    my ($driver, $dsn, $user, $pass) = @_ ? @_ : @ARGV;
+    my ($dsn, $user, $pass, $driver) = @_ ? @_ : @ARGV;
     my $dbh = DBI->connect($dsn, $user, $pass, {AutoCommit=>1, RaiseError=>1});
     $driver = "<foo>" unless defined $driver;
 
@@ -316,7 +316,7 @@ sub write_typeinfo
 # Transfer this to ${driver}.pm
 
 # The type_info_all function was automatically generated by
-# DBI::DBD::Metadata::write_typeinfo v$DBI::DBD::Metadata::VERSION.
+# DBI::DBD::Metadata::write_typeinfo_pm v$DBI::DBD::Metadata::VERSION.
 
 package DBD::${driver}::db;         # This line can be removed once transferred.
 
@@ -331,7 +331,7 @@ package DBD::${driver}::db;         # This line can be removed once transferred.
 # Don't forget to add version and intellectual property control information.
 
 # The \%type_info_all hash was automatically generated by
-# DBI::DBD::Metadata::write_typeinfo v$DBI::DBD::Metadata::VERSION.
+# DBI::DBD::Metadata::write_typeinfo_pm v$DBI::DBD::Metadata::VERSION.
 
 package DBD::${driver}::TypeInfo;
 
